==> hs-terminfo-0.3.2.4.tbz: lib/ghc-7.4.1/cabal/terminfo-0.3.2.4/register.sh <==
#!/bin/sh
echo 'name: terminfo
version: 0.3.2.4
id: terminfo-0.3.2.4-26df927d43aec19c7cdd2167fc0b87ea

license: BSD3
copyright: (c) Judah Jacobson
maintainer: Judah Jacobson <judah.jacobson@gmail.com>
stability: Experimental
homepage: http://code.haskell.org/terminfo
package-url:
synopsis: Haskell bindings to the terminfo library.
description: This library provides an interface to the terminfo database (via bindings to the
             curses library).  Terminfo allows POSIX systems to interact with a variety of terminals
             using a standard set of capabilities.
category: User Interfaces
author: Judah Jacobson
exposed: True
exposed-modules: System.Console.Terminfo
                 System.Console.Terminfo.Base System.Console.Terminfo.Cursor
                 System.Console.Terminfo.Color System.Console.Terminfo.Edit
                 System.Console.Terminfo.Effects System.Console.Terminfo.Keys
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.1/cabal/terminfo-0.3.2.4
library-dirs: /usr/local/lib/ghc-7.4.1/cabal/terminfo-0.3.2.4
              /usr/local/lib
hs-libraries: HSterminfo-0.3.2.4
extra-libraries: ncursesw
extra-ghci-libraries:
include-dirs: /usr/local/include
includes: ncurses.h term.h
depends: base-4.5.0.0-1a022b3476300ed3e5bfdd46dd7221d0
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.1/cabal/terminfo-0.3.2.4/html/terminfo.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.1/cabal/terminfo-0.3.2.4/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-terminfo-0.3.2.5_1.tbz: lib/ghc-7.4.2/cabal/terminfo-0.3.2.5/register.sh <==
#!/bin/sh
echo 'name: terminfo
version: 0.3.2.5
id: terminfo-0.3.2.5-4d1c81be8d263b97c08424418c50ad5a

license: BSD3
copyright: (c) Judah Jacobson
maintainer: Judah Jacobson <judah.jacobson@gmail.com>
stability: Experimental
homepage: http://code.haskell.org/terminfo
package-url:
synopsis: Haskell bindings to the terminfo library.
description: This library provides an interface to the terminfo database (via bindings to the
             curses library).  Terminfo allows POSIX systems to interact with a variety of terminals
             using a standard set of capabilities.
category: User Interfaces
author: Judah Jacobson
exposed: True
exposed-modules: System.Console.Terminfo
                 System.Console.Terminfo.Base System.Console.Terminfo.Cursor
                 System.Console.Terminfo.Color System.Console.Terminfo.Edit
                 System.Console.Terminfo.Effects System.Console.Terminfo.Keys
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/terminfo-0.3.2.5
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/terminfo-0.3.2.5
              /usr/lib /usr/local/lib
hs-libraries: HSterminfo-0.3.2.5
extra-libraries: ncursesw
extra-ghci-libraries:
include-dirs: /usr/include /usr/local/include
includes: ncurses.h term.h
depends: base-4.5.1.0-f58939ca866a8377999e7a71aa62d1d0
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/terminfo-0.3.2.5/html/terminfo.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/terminfo-0.3.2.5/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
